import * as echarts from 'echarts'
import { setOptions, nowSize } from "./echarts";
import { DataSourceArr } from '../utils/data/select-data'

let yxfx = null
export function setYxfx(ele, dataIn) {
  console.log(dataIn)
  let points = []
  let links = []
  let colorList = {
    'DATA_SERVER': '#409FFF',
    'INTERFACE': '#FFBF00',
    'NORMAL_DATA': '#9fdabf',
    'SPATIAL_DATA': '#D9D9D9'
  }
  function initData(data, parentName) {
    if (parentName) {
      links.push({
        source: data.name,
        target: parentName,
        lineStyle: { color: colorList[data.type] }
      })
    }
    points.push({ name: data.name, category: DataSourceArr.getLabel(data.type) })
    if (data.bePointedAt) {
      data.bePointedAt.forEach(i => {
        initData(i, data.name)
      })
    }
  }

  initData(dataIn, null)
  console.log(points, links)

  let option = {
    backgroundColor: '#fff',
    tooltip: { show: false },
    legend: {
      show: true,
      itemGap: nowSize(30),
      data: ['空间数据','非空间数据','服务','接口'],
      textStyle: {
        color: "#333",
        fontSize: nowSize(18)
      },
      icon: "circle",
      bottom: "3%",
    },
    series: [
      {
        type: 'graph',
        layout: 'force',
        edgeSymbol: ['none', 'arrow'],
        force: {
          repulsion: 3000,
          edgeLength: 200,
        },
        roam: true,
        zoom: 0.7,
        label: {
          show: true,
          color: '#fff',
          fontWeight: 'bold'
        },
        draggable: true,
        data: points,
        links: links,
        lineStyle: {
          width: nowSize(2),
          curveness: 0,
        },
        categories: [
          { name: '空间数据', symbol: 'circle', symbolSize: nowSize(200), itemStyle: { color: '#409FFF' }, label: { fontSize: nowSize(30) }},
          { name: '非空间数据', symbol: 'circle', symbolSize: nowSize(180), itemStyle: { color: '#FFBF00' }, label: { fontSize: nowSize(26) }},
          { name: '服务', symbol: 'diamond', symbolSize: nowSize(160), itemStyle: { color: '#9FDABF' }, label: { fontSize: nowSize(22) }},
          { name: '接口', symbol: 'roundRect', symbolSize: nowSize(140), itemStyle: { color: '#D9D9D9' }, label: { fontSize: nowSize(18) }},
        ],
      },
    ],
  }

  yxfx = setOptions(ele, option)
}